@@ -9,10 +9,7 @@
 #'
 #' @return [[data.frame]]
 qc_features <- function(data, id_colname) {
-  nested_data_df <- tidyr::nest(dplyr::group_by(.data = data, get(id_colname)))
-  colnames(nested_data_df)[1] <- id_colname
-
-  output <- lapply(X = nested_data_df[["data"]], FUN = function(.data) {
+  output <- lapply(X = split(data, data[[id_colname]]), FUN = function(.data) {
     positives <- .data[.data[["CodeClass"]] %in% "Positive", c("Name", "Count")]
     counts <- .data[grep("Endogenous", .data[["CodeClass"]]), ][["Count"]]
 
@@ -28,20 +25,20 @@ qc_features <- function(data, id_colname) {
       lod <- 0
     }
     fov <- qc_imaging(
-      fov_counted = as.numeric(unique(.data[["lane_FovCounted"]])),
-      fov_count = as.numeric(unique(.data[["lane_FovCount"]]))
+      fov_counted = as.numeric(unique(.data[["Lane_Attributes.lane_FovCounted"]])),
+      fov_count = as.numeric(unique(.data[["Lane_Attributes.lane_FovCount"]]))
     )
 
     mean_count <- round(mean(counts), 2)
     median_count <- stats::median(counts)
 
     c(
-      "Date" = unique(.data[["sample_Date"]]),
-      "ID" = unique(.data[["lane_ID"]]),
-      "BD" = unique(.data[["lane_BindingDensity"]]),
-      "ScannerID" = unique(.data[["lane_ScannerID"]]),
-      "StagePosition" = unique(.data[["lane_StagePosition"]]),
-      "CartridgeID" = unique(.data[["lane_CartridgeID"]]),
+      "Date" = unique(.data[["Sample_Attributes.sample_Date"]]),
+      "ID" = unique(.data[["Lane_Attributes.lane_ID"]]),
+      "BD" = unique(.data[["Lane_Attributes.lane_BindingDensity"]]),
+      "ScannerID" = unique(.data[["Lane_Attributes.lane_ScannerID"]]),
+      "StagePosition" = unique(.data[["Lane_Attributes.lane_StagePosition"]]),
+      "CartridgeID" = unique(.data[["Lane_Attributes.lane_CartridgeID"]]),
       "FoV" = fov,
       "PCL" = ifelse(is.na(pcl), 0, pcl),
       "LoD" = lod,
@@ -49,13 +46,13 @@ qc_features <- function(data, id_colname) {
       "MedC" = median_count
     )
   })
-
-  output <- as.data.frame(do.call("rbind", output), stringsAsFactors = FALSE)
-  output[[id_colname]] <- nested_data_df[[id_colname]]
-  output[c("BD", "FoV", "PCL", "LoD", "MC", "MedC")] <- lapply(
-    X = output[c("BD", "FoV", "PCL", "LoD", "MC", "MedC")],
-    FUN = as.numeric
+  output <- data.table::as.data.table(
+    x = do.call("rbind", output),
+    keep.rownames = id_colname
   )
-
-  output
-}
\ No newline at end of file
+  metrics_in <- intersect(names(output), c("BD", "FoV", "PCL", "LoD", "MC", "MedC"))
+  output[
+    j = c(metrics_in) := lapply(.SD, as.numeric),
+    .SDcols = c(metrics_in)
+  ]
+}
