@@ -19,20 +19,18 @@ qc_rcc <- function(
   normalisation_method,
   n_comp
 ) {
+  Name <- CodeClass <- NULL # no visible binding for global variable
   has_hkg <- grepl("Housekeeping", nacho_df[["CodeClass"]])
   if (is.null(housekeeping_genes) & any(has_hkg)) {
     housekeeping_genes <- nacho_df[["Name"]][has_hkg]
     housekeeping_genes <- unique(housekeeping_genes)
   }
 
-  control_genes_df <- nacho_df[nacho_df[["Name"]] %in% housekeeping_genes | !grepl("Endogenous", nacho_df[["CodeClass"]]), ]
-
   control_genes_df <- format_counts(
-    data = control_genes_df,
+    data = nacho_df[Name %in% housekeeping_genes | !grepl("Endogenous", CodeClass)],
     id_colname = id_colname,
     count_column = "Count"
   )
-  rownames(control_genes_df) <- control_genes_df[["Name"]]
 
   probes_to_exclude <- probe_exclusion(control_genes_df = control_genes_df)
 
@@ -52,30 +50,34 @@ qc_rcc <- function(
       exclude_probes = probes_to_exclude
     )
 
-    tmp_counts <- dplyr::full_join(
-      x = nacho_df[, c(id_colname, setdiff(colnames(nacho_df), colnames(temp_facs)))],
+    tmp_counts <- merge(
+      x = nacho_df[
+        j = .SD,
+        .SDcols = c(id_colname, setdiff(colnames(nacho_df), colnames(temp_facs)))
+      ],
       y = temp_facs,
-      by = id_colname
+      by = id_colname,
+      all = TRUE
     )
     tmp_counts[["count_norm"]] <- normalise_counts(data = tmp_counts, housekeeping_norm = FALSE)
 
     predicted_housekeeping <- find_housekeeping(
-      data = tmp_counts,
+      data = data.table::setDT(tmp_counts),
       id_colname = id_colname,
       count_column = "count_norm"
     )
 
     if (is.null(predicted_housekeeping) | length(predicted_housekeeping) == 0) {
-      message('[NACHO] Could not find suitable houskeeping genes, default will be used.')
+      message("[NACHO] Could not find suitable houskeeping genes, default will be used.")
     } else {
       message(
-        '[NACHO] The following predicted housekeeping genes will be used for normalisation:\n',
+        "[NACHO] The following predicted housekeeping genes will be used for normalisation:\n",
           paste0("  - ", predicted_housekeeping, collapse = "\n")
       )
       housekeeping_genes <- predicted_housekeeping
-      control_genes_df <- nacho_df[nacho_df[["Name"]] %in% predicted_housekeeping, ]
+
       control_genes_df <- format_counts(
-        data = control_genes_df,
+        data = nacho_df[Name %in% housekeeping_genes],
         id_colname = id_colname,
         count_column = "Count"
       )
@@ -99,7 +101,7 @@ qc_rcc <- function(
     id_colname = id_colname,
     count_column = "Count"
   )
-  counts_df <- counts_df[, sapply(X = counts_df, FUN = is.numeric)]
+  counts_df <- counts_df[j = .SD, .SDcols = is.numeric]
 
   if (n_comp > (ncol(counts_df) - 1)) {
     message(paste('"n_comp" has been set to "n-1:"', (ncol(counts_df) - 1)))
@@ -117,27 +119,32 @@ qc_rcc <- function(
   pcas <- qc_pca(counts = counts_df_tmp, n_comp = n_comp)
 
   pcsum <- as.data.frame(t(pcas[["pcsum"]]), stringsAsFactors = FALSE)
-  rownames(pcsum) <- pcsum[["PC"]] <- sprintf("PC%02d", as.numeric(gsub("PC", "", rownames(pcsum))))
+  rownames(pcsum) <- pcsum[["PC"]] <- sprintf("PC%02d", as.numeric(sub("PC", "", rownames(pcsum))))
 
   pcas_pc <- as.data.frame(pcas[["pc"]], stringsAsFactors = FALSE)
-  colnames(pcas_pc) <- sprintf("PC%02d", as.numeric(gsub("PC", "", colnames(pcas_pc))))
+  colnames(pcas_pc) <- sprintf("PC%02d", as.numeric(sub("PC", "", colnames(pcas_pc))))
   pcas_pc[[id_colname]] <- rownames(pcas_pc)
 
-
-  facs_pc_qc <- dplyr::full_join(
-    x = dplyr::full_join(
+  facs_pc_qc <- merge(
+    x = merge(
       x = qc_values,
       y = pcas_pc,
-      by = id_colname
+      by = id_colname,
+      all = TRUE
     ),
     y = norm_factor,
-    by = id_colname
+    by = id_colname,
+    all = TRUE
   )
 
-  nacho_out <- dplyr::full_join(
-    x = nacho_df[, c(id_colname, setdiff(colnames(nacho_df), colnames(facs_pc_qc)))],
+  nacho_out <- merge(
+    x = nacho_df[
+      j = .SD,
+      .SDcols = c(id_colname, setdiff(colnames(nacho_df), colnames(facs_pc_qc)))
+    ],
     y = facs_pc_qc,
-    by = id_colname
+    by = id_colname,
+    all = TRUE
   )
 
   list(
@@ -150,6 +157,6 @@ qc_rcc <- function(
     n_comp = n_comp,
     data_directory = data_directory,
     pc_sum = pcsum,
-    nacho = as.data.frame(nacho_out, stringsAsFactors = FALSE)
+    nacho = nacho_out
   )
-}
\ No newline at end of file
+}
